@@ -18,7 +18,7 @@ from analysis_runner.git import (
 )
 
 
-HAIL_VERSION = '0.2.100'
+HAIL_VERSION = '0.2.102'
 DATAPROC_IMAGE = (
     f'australia-southeast1-docker.pkg.dev/analysis-runner/images/'
     f'dataproc:hail-{HAIL_VERSION}'
@@ -292,7 +292,7 @@ def _add_submit_job(
         f'hailctl dataproc submit '
         f'--region={region} '
         + (f'--pyfiles {",".join(pyfiles)} ' if pyfiles else '')
-        + f'{cluster_id} {script} '
+        + f'{cluster_id} -- {script} '
     )
     return main_job
 
